![PypiVersion](https://img.shields.io/pypi/v/finite-groups?color=blue)
![PythonVersion](https://img.shields.io/pypi/pyversions/finite-groups)
![Downloads](https://img.shields.io/pypi/dm/finite-groups)
![Size](https://img.shields.io/github/repo-size/CrisLeaf/finite-groups?color=green)

# Finite-Groups
**Finite-Groups** is a Python package for finite groups computations.

Author email: [Cris](mailto:cristobal_javier@hotmail.com)

Dependencies
------------
- Python (>= 3.9)
- NumPy (>=1.19.5)

Installation
------------
On the terminal run:

    pip install finite-groups


Source Code
-----------
To get the latest code sources run:

    git clone https://github.com/CrisLeaf/finite-groups


Updates
-------
- [X] PermutationGroup class.
- [ ] Action class.
- [ ] Representation class.
- [ ] Documentation page.


Support
-------
Give a :star: if you like this project :hugs:.